{% extends "userface/adminportal.html" %}


 <title>My Parking</title>
  {% block active %}
              <li class="nav-item">
                <a class="nav-link" href="{% url 'userface:portal'%}">
                  <span data-feather="home"></span>
                  Dashboard <span class="sr-only">(current)</span>
                </a>
              </li>
              <li class="nav-item">
                <a class="nav-link active" href="{% url 'userface:my-vehicles'%}">
                  <span data-feather="truck"></span>
                  My Vehicles
                </a>
              </li>
              <li class="nav-item">
                <a class="nav-link" href="{% url 'userface:myparking'%}">
                  <span data-feather="home"></span>
                  My parking
                </a>
              </li>
              {% endblock active %}




{% block title %}  <h1 class="h2">Vehicle List</h1>  {% endblock title %}

  {% block action %}
   <a href="{% url 'userface:registervehicle'%}" class="btn btn-sm btn-outline-secondary">Register Vehicle</a>
  {% endblock action %}
{% block content %}

<style>
ul {
  list-style-type: none;
}
</style>

    {% if vehicle_list %}
    
    <ul style="margin:10px;">
<div class="list-group">

      {% for vehicle in vehicle_list %}
      
          
          <li class="list-group-item"> {{ vehicle.make }} {{vehicle.model}}</li>
        
      {% endfor %}
      </div>
    </ul>

    {% else %}
      <p>You have no vehicles</p>
    {% endif %}
{% endblock %}

