#!/usr/bin/env python

import os

import sys



def main():

    os.environ.setdefault('DJANGO_SETTINGS_MODULE', 'drive.settings')

    try:

        from django.core.management import execute_from_command_line

    except ImportError as exc:

        raise ImportError(

            "Couldn't import Libraries. Are you sure they are installed and "

            "available on your PYTHONPATH environment variable? Did you "

            "forget to activate a virtual environment?"

        ) from exc

    execute_from_command_line(["manage.py", "runserver", "0.0.0.0:8000"])





if __name__ == '__main__':

    main()