
{% extends "userface/user_vehicle_list.html" %}




{% block title %}  <h1 class="h2">Register Vehicle</h1>  {% endblock title %}

  {% block action %}
   <a href="{% url 'userface:my-vehicles'%}" class="btn btn-sm btn-outline-secondary">Your Vehicles</a>
  {% endblock action %}


{% block content %}
{% load crispy_forms_tags %}
  <form method="post">
    {% csrf_token %}
    <div class="form-row">
      <div class="form-group col-md-6 mb-0">
        {{ form.make|as_crispy_field }}
      </div>
      <div class="form-group col-md-6 mb-0">
        {{ form.model|as_crispy_field }}
      </div>
      <div class="form-group col-md-6 mb-0">
        {{ form.plateNum|as_crispy_field }}
      </div>
    </div>
    <button type = "submit" class="btn btn-sm btn-outline-secondary">Submit</button>
  </form>
{% endblock %}