{% extends "userface/book.html" %}
{% block body %}
<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <a class="text-justify" style="margin-left: 15px">Your Parking has been booked!</a>
</head>
<body>

</body>
</html>
{% endblock body %}