{% load static %}

  <head>
    <meta charset="utf-8">
    <meta name="viewport" content="width=device-width, initial-scale=1, shrink-to-fit=no">
    <meta name="description" content="">
    <meta name="author" content="">
    <link rel="icon" href="/docs/4.0/assets/img/favicons/favicon.ico">

    <link rel="canonical" href="https://getbootstrap.com/docs/4.0/examples/cover/">
    <!-- Bootstrap core CSS -->
    <link href="https://stackpath.bootstrapcdn.com/bootstrap/4.1.3/css/bootstrap.min.css" rel="stylesheet">

    <!-- Custom styles for this template -->
    <link rel="stylesheet" href="{% static 'css/home.css' %}">
  </head>

  <body class="text-center">

    <div class="cover-container d-flex h-100 p-3 mx-auto flex-column">
      <header class="masthead mb-auto">
        <div class="inner">
          <nav class="nav nav-masthead justify-content-center">
            <a class="nav-link active" href="{% url 'login'%}?next={% url 'userface:search'%}">Login</a>
            <a class="nav-link active" href="{% url 'userface:register'%}?next={{request.path}}">Register</a>
          </nav>
        </div>
      </header>
      {%  block search %}
      <main role="main" class="inner cover">
        <h1 class="cover-heading">Welcome to Driveways!</h1>

      </main>
      {% endblock search %}
       <div class="flex" style="margin: 10px;padding: 10px; border-top:solid white; border-width: medium;"></div>

      <footer class="mastfoot mt-auto">
        <div class="inner">
        </div>
      </footer>
    </div>


  </body>

