{% extends "base_generic.html" %}

{% block content %}

{% load crispy_forms_tags %}
  <form method="post" >
    {% csrf_token %}
    <div>
    <div class="form-row">
        <div class="form-group col-md-6 mb-0">
        {{ form.email|as_crispy_field }}
        </div>
      </div>
      <div class="form-row">
        <div class="form-group col-md-6 mb-0">
        {{ form.username|as_crispy_field }}
        </div>
      </div>
      <div class="form-row">
        <div class="form-group col-md-6 mb-0">
        {{ form.first_name|as_crispy_field }}
        </div>
      </div>
      <div class="form-row">
        <div class="form-group col-md-6 mb-0">
        {{ form.last_name|as_crispy_field }}
        </div>
      </div>
      <div class="form-row">
        <div class="form-group col-md-6 mb-0">
        {{ form.password1|as_crispy_field }}
        </div>
      </div>
      <div class="form-row">
        <div class="form-group col-md-6 mb-0">
        {{ form.password2|as_crispy_field }}
        </div>
      </div>
      <button type="submit" class="btn btn-primary">Submit</button>
    </div>

  </form>
{% endblock content %}

